translate.storage.tiki.TikiStore

Package translate :: Package storage :: Module tiki :: Class TikiStore |
[hide private]
[frames] | no frames]

# Class TikiStore

source code

Represents a tiki language.php file.

Nested Classes | [hide private]
Inherited from `base.TranslationStore`: `UnitClass`

Instance Methods | [hide private]
__init__(self, inputfile=None) If an inputfile is specified it will be parsed. | source code
__str__(self) Will return a formatted tiki-style language.php file. | source code
_tiki_header(self) Returns a tiki-file header string. | source code
_tiki_footer(self) Returns a tiki-file footer string. | source code
parse(self, input) Parse the given input into source units. | source code
Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `findid`, `findunit`, `findunits`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
Inherited from `base.TranslationStore`: `Extensions`, `Mimetypes`, `Name`, `suggestions_in_format` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, inputfile=None) (Constructor) | source code
If an inputfile is specified it will be parsed. Parameters: `inputfile` - Either a string or a filehandle of the source file Overrides: object.__init__

### __str__(self) (Informal representation operator) | source code
Will return a formatted tiki-style language.php file. Overrides: object.__str__

### parse(self, input) | source code
Parse the given input into source units. Parameters: `input` - the source, either a string or filehandle Overrides: base.TranslationStore.parse